gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r28447 - in gnunet/src: fs include


From: gnunet
Subject: [GNUnet-SVN] r28447 - in gnunet/src: fs include
Date: Thu, 8 Aug 2013 07:36:25 +0200

Author: grothoff
Date: 2013-08-08 07:36:25 +0200 (Thu, 08 Aug 2013)
New Revision: 28447

Modified:
   gnunet/src/fs/fs_namespace.c
   gnunet/src/fs/gnunet-pseudonym.c
   gnunet/src/fs/gnunet-publish.c
   gnunet/src/include/gnunet_crypto_lib.h
Log:
-doxygen fixes

Modified: gnunet/src/fs/fs_namespace.c
===================================================================
--- gnunet/src/fs/fs_namespace.c        2013-08-08 05:24:57 UTC (rev 28446)
+++ gnunet/src/fs/fs_namespace.c        2013-08-08 05:36:25 UTC (rev 28447)
@@ -120,6 +120,7 @@
  * Return the name of the directory in which we store
  * the update information graph for the given local namespace.
  *
+ * @param h file-sharing handle
  * @param ns namespace handle
  * @return NULL on error, otherwise the name of the directory
  */
@@ -183,9 +184,9 @@
 
 
 /**
- * Write the namespace update node graph to a file.
+ * Write a namespace's update node graph to a file.
  *
- * @param ns namespace to dump
+ * @param uig update information graph to dump
  */
 static void
 write_update_information_graph (struct GNUNET_FS_UpdateInformationGraph *uig)

Modified: gnunet/src/fs/gnunet-pseudonym.c
===================================================================
--- gnunet/src/fs/gnunet-pseudonym.c    2013-08-08 05:24:57 UTC (rev 28446)
+++ gnunet/src/fs/gnunet-pseudonym.c    2013-08-08 05:36:25 UTC (rev 28447)
@@ -180,7 +180,7 @@
  *
  * @param cls closure, NULL
  * @param ego ego handle
- * @param ego_ctx context for application to store data for this ego
+ * @param ctx context for application to store data for this ego
  *                 (during the lifetime of this process, initially NULL)
  * @param name name assigned by the user for this ego,
  *                   NULL if the user just deleted the ego and it

Modified: gnunet/src/fs/gnunet-publish.c
===================================================================
--- gnunet/src/fs/gnunet-publish.c      2013-08-08 05:24:57 UTC (rev 28446)
+++ gnunet/src/fs/gnunet-publish.c      2013-08-08 05:36:25 UTC (rev 28447)
@@ -689,7 +689,7 @@
  *
  * @param cls closure with 'const char *' of filename to publish
  * @param ego ego handle
- * @param ego_ctx context for application to store data for this ego
+ * @param ctx context for application to store data for this ego
  *                 (during the lifetime of this process, initially NULL)
  * @param name name assigned by the user for this ego,
  *                   NULL if the user just deleted the ego and it

Modified: gnunet/src/include/gnunet_crypto_lib.h
===================================================================
--- gnunet/src/include/gnunet_crypto_lib.h      2013-08-08 05:24:57 UTC (rev 
28446)
+++ gnunet/src/include/gnunet_crypto_lib.h      2013-08-08 05:36:25 UTC (rev 
28447)
@@ -929,13 +929,13 @@
 /**
  * Derive key material from a public and a private ECC key.
  *
  * @param key private key to use for the ECDH (x)
  * @param pub public key to use for the ECDY (yG)
  * @param key_material where to write the key material (xyG)
  * @return GNUNET_SYSERR on error, GNUNET_OK on success
  */
 int
-GNUNET_CRYPTO_ecc_ecdh (const struct GNUNET_CRYPTO_EccPrivateKey *key,
+GNUNET_CRYPTO_ecc_ecdh (const struct GNUNET_CRYPTO_EccPrivateKey *priv,
                         const struct GNUNET_CRYPTO_EccPublicKey *pub,
                         struct GNUNET_HashCode *key_material);
 
@@ -929,13 +929,13 @@
  * Derive key material from a public and a private ECC key.
  *
- * @param key private key to use for the ECDH (x)
+ * @param priv private key to use for the ECDH (x)
  * @param pub public key to use for the ECDY (yG)
  * @param key_material where to write the key material (xyG)




reply via email to

[Prev in Thread] Current Thread [Next in Thread]